@@ -48,17 +48,17 @@ typedef struct _GeditHistoryEntryPrivate GeditHistoryEntryPrivate;
 
 struct _GeditHistoryEntryClass
 {
-	GtkComboBoxEntryClass parent_class;
+	GtkComboBoxTextClass parent_class;
 };
 
 struct _GeditHistoryEntry
 {
-	GtkComboBoxEntry parent_instance;
+	GtkComboBoxText parent_instance;
 
 	GeditHistoryEntryPrivate *priv;
 };
 
-GType		 gedit_history_entry_get_type	(void) G_GNUC_CONST;
+GType		 gedit_history_entry_get_type		(void) G_GNUC_CONST;
 
 GtkWidget	*gedit_history_entry_new		(const gchar       *history_id,
 							 gboolean           enable_completion);
@@ -76,8 +76,6 @@ void		 gedit_history_entry_set_history_length	(GeditHistoryEntry *entry,
 
 guint		 gedit_history_entry_get_history_length	(GeditHistoryEntry *gentry);
 
-gchar		*gedit_history_entry_get_history_id	(GeditHistoryEntry *entry);
-
 void             gedit_history_entry_set_enable_completion 
 							(GeditHistoryEntry *entry,
 							 gboolean           enable);
@@ -94,4 +92,5 @@ void		gedit_history_entry_set_escape_func	(GeditHistoryEntry *entry,
 G_END_DECLS
 
 #endif /* __GEDIT_HISTORY_ENTRY_H__ */
-/* ex:ts=8:noet: */
+
+/* ex:set ts=8 noet: */
