@@ -21,10 +21,10 @@ __all__ = ('Capture', )
 import os, sys, signal
 import locale
 import subprocess
-import gobject
 import fcntl
+from gi.repository import GObject
 
-class Capture(gobject.GObject):
+class Capture(GObject.Object):
     CAPTURE_STDOUT = 0x01
     CAPTURE_STDERR = 0x02
     CAPTURE_BOTH   = 0x03
@@ -33,14 +33,14 @@ class Capture(gobject.GObject):
     WRITE_BUFFER_SIZE = 0x4000
 
     __gsignals__ = {
-        'stdout-line'  : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (gobject.TYPE_STRING,)),
-        'stderr-line'  : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (gobject.TYPE_STRING,)),
-        'begin-execute': (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, tuple()),
-        'end-execute'  : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (gobject.TYPE_INT,))
+        'stdout-line'  : (GObject.SIGNAL_RUN_LAST, GObject.TYPE_NONE, (GObject.TYPE_STRING,)),
+        'stderr-line'  : (GObject.SIGNAL_RUN_LAST, GObject.TYPE_NONE, (GObject.TYPE_STRING,)),
+        'begin-execute': (GObject.SIGNAL_RUN_LAST, GObject.TYPE_NONE, tuple()),
+        'end-execute'  : (GObject.SIGNAL_RUN_LAST, GObject.TYPE_NONE, (GObject.TYPE_INT,))
     }
 
     def __init__(self, command, cwd = None, env = {}):
-        gobject.GObject.__init__(self)
+        GObject.GObject.__init__(self)
         self.pipe = None
         self.env = env
         self.cwd = cwd
@@ -100,8 +100,8 @@ class Capture(gobject.GObject):
             flags = fcntl.fcntl(self.pipe.stdout.fileno(), fcntl.F_GETFL) | os.O_NONBLOCK
             fcntl.fcntl(self.pipe.stdout.fileno(), fcntl.F_SETFL, flags)
 
-            gobject.io_add_watch(self.pipe.stdout,
-                                 gobject.IO_IN | gobject.IO_HUP,
+            GObject.io_add_watch(self.pipe.stdout,
+                                 GObject.IOCondition.IN | GObject.IOCondition.HUP,
                                  self.on_output)
 
         if self.flags & self.CAPTURE_STDERR:
@@ -109,20 +109,20 @@ class Capture(gobject.GObject):
             flags = fcntl.fcntl(self.pipe.stderr.fileno(), fcntl.F_GETFL) | os.O_NONBLOCK
             fcntl.fcntl(self.pipe.stderr.fileno(), fcntl.F_SETFL, flags)
 
-            gobject.io_add_watch(self.pipe.stderr,
-                                 gobject.IO_IN | gobject.IO_HUP,
+            GObject.io_add_watch(self.pipe.stderr,
+                                 GObject.IOCondition.IN | GObject.IOCondition.HUP,
                                  self.on_output)
 
-        # IO        
+        # IO
         if self.input_text is not None:
             # Write async, in chunks of something
             self.write_buffer = str(self.input_text)
 
             if self.idle_write_chunk():
-                self.idle_write_id = gobject.idle_add(self.idle_write_chunk)
+                self.idle_write_id = GObject.idle_add(self.idle_write_chunk)
 
         # Wait for the process to complete
-        gobject.child_watch_add(self.pipe.pid, self.on_child_end)
+        GObject.child_watch_add(self.pipe.pid, self.on_child_end)
 
     def idle_write_chunk(self):
         if not self.pipe:
@@ -140,6 +140,7 @@ class Capture(gobject.GObject):
                 self.pipe.stdin.close()
                 
                 self.idle_write_id = 0
+
                 return False
             else:
                 self.write_buffer = self.write_buffer[m:]
@@ -151,49 +152,51 @@ class Capture(gobject.GObject):
             return False
 
     def on_output(self, source, condition):
-        line = source.read()
+        if condition & (GObject.IO_IN | GObject.IO_PRI):
+            line = source.read()
 
-        if len(line) > 0:
-            try:
-                line = unicode(line, 'utf-8')
-            except:
-                line = unicode(line,
-                               locale.getdefaultlocale()[1],
-                               'replace')
+            if len(line) > 0:
+                try:
+                    line = unicode(line, 'utf-8')
+                except:
+                    line = unicode(line,
+                                   locale.getdefaultlocale()[1],
+                                   'replace')
 
-            self.read_buffer += line
-            lines = self.read_buffer.splitlines(True)
-            
-            if not lines[-1].endswith("\n"):
-                self.read_buffer = lines[-1]
-                lines = lines[0:-1]
-            else:
-                self.read_buffer = ''
-
-            for line in lines:
-                if not self.pipe or source == self.pipe.stdout:
-                    self.emit('stdout-line', line)
+                self.read_buffer += line
+                lines = self.read_buffer.splitlines(True)
+                
+                if not lines[-1].endswith("\n"):
+                    self.read_buffer = lines[-1]
+                    lines = lines[0:-1]
                 else:
-                    self.emit('stderr-line', line)
+                    self.read_buffer = ''
 
-            return True
-        else:
+                for line in lines:
+                    if not self.pipe or source == self.pipe.stdout:
+                        self.emit('stdout-line', line)
+                    else:
+                        self.emit('stderr-line', line)
+
+        if condition & ~(GObject.IO_IN | GObject.IO_PRI):
             if self.read_buffer:
                 if source == self.pipe.stdout:
                     self.emit('stdout-line', self.read_buffer)
                 else:
                     self.emit('stderr-line', self.read_buffer)
-                
+
                 self.read_buffer = ''
-            
+
             self.pipe = None
 
-        return False
+            return False
+        else:
+            return True
 
     def stop(self, error_code = -1):
         if self.pipe is not None:
             if self.idle_write_id:
-                gobject.source_remove(self.idle_write_id)
+                GObject.source_remove(self.idle_write_id)
                 self.idle_write_id = 0
 
             if not self.tried_killing:
@@ -205,6 +208,6 @@ class Capture(gobject.GObject):
     def on_child_end(self, pid, error_code):
         # In an idle, so it is emitted after all the std*-line signals
         # have been intercepted
-        gobject.idle_add(self.emit, 'end-execute', error_code)
+        GObject.idle_add(self.emit, 'end-execute', error_code)
 
 # ex:ts=4:et:
