@@ -49,12 +49,13 @@
 #define FILEBROWSER_FILTER_MODE		"filter-mode"
 #define FILEBROWSER_FILTER_PATTERN	"filter-pattern"
 
-#define NAUTILUS_BASE_SETTINGS		"org.gnome.Nautilus.preferences"
+#define NAUTILUS_BASE_SETTINGS		"org.gnome.nautilus.preferences"
+#define NAUTILUS_FALLBACK_SETTINGS	"org.gnome.gedit.plugins.filebrowser.nautilus"
 #define NAUTILUS_CLICK_POLICY_KEY	"click-policy"
 #define NAUTILUS_ENABLE_DELETE_KEY	"enable-delete"
 #define NAUTILUS_CONFIRM_TRASH_KEY	"confirm-trash"
 
-#define TERMINAL_BASE_SETTINGS		"org.gnome.Desktop.Applications.Terminal"
+#define TERMINAL_BASE_SETTINGS		"org.gnome.desktop.default-applications.terminal"
 #define TERMINAL_EXEC_KEY		"exec"
 
 #define GEDIT_FILE_BROWSER_PLUGIN_GET_PRIVATE(object)	(G_TYPE_INSTANCE_GET_PRIVATE ((object), GEDIT_TYPE_FILE_BROWSER_PLUGIN, GeditFileBrowserPluginPrivate))
@@ -80,6 +81,12 @@ struct _GeditFileBrowserPluginPrivate
 	guint			confirm_trash_handle;
 };
 
+enum
+{
+	PROP_0,
+	PROP_WINDOW
+};
+
 static void gedit_window_activatable_iface_init	(GeditWindowActivatableInterface *iface);
 
 static void on_location_activated_cb     (GeditFileBrowserWidget        *widget,
@@ -124,14 +131,46 @@ G_DEFINE_DYNAMIC_TYPE_EXTENDED (GeditFileBrowserPlugin,
 				_gedit_file_browser_widget_register_type	(type_module);		\
 )
 
+static GSettings *
+settings_try_new (const gchar *schema)
+{
+	const gchar * const * schemas;
+	GSettings *settings = NULL;
+
+	schemas = g_settings_list_schemas ();
+
+	if (schemas == NULL)
+	{
+		return NULL;
+	}
+
+	for (; *schemas != NULL; schemas++)
+	{
+		if (g_strcmp0 (*schemas, schema) == 0)
+		{
+			settings = g_settings_new (schema);
+			break;
+		}
+	}
+
+	return settings;
+}
+
 static void
 gedit_file_browser_plugin_init (GeditFileBrowserPlugin *plugin)
 {
+	
+
 	plugin->priv = GEDIT_FILE_BROWSER_PLUGIN_GET_PRIVATE (plugin);
 
 	plugin->priv->settings = g_settings_new (FILEBROWSER_BASE_SETTINGS);
-	plugin->priv->nautilus_settings = g_settings_new (NAUTILUS_BASE_SETTINGS);
 	plugin->priv->terminal_settings = g_settings_new (TERMINAL_BASE_SETTINGS);
+	plugin->priv->nautilus_settings = settings_try_new (NAUTILUS_BASE_SETTINGS);
+
+	if (plugin->priv->nautilus_settings == NULL)
+	{
+		plugin->priv->nautilus_settings = g_settings_new (NAUTILUS_FALLBACK_SETTINGS);
+	}
 }
 
 static void
@@ -157,9 +196,55 @@ gedit_file_browser_plugin_dispose (GObject *object)
 		plugin->priv->terminal_settings = NULL;
 	}
 
+	if (plugin->priv->window != NULL)
+	{
+		g_object_unref (plugin->priv->window);
+		plugin->priv->window = NULL;
+	}
+
 	G_OBJECT_CLASS (gedit_file_browser_plugin_parent_class)->dispose (object);
 }
 
+static void
+gedit_file_browser_plugin_set_property (GObject      *object,
+                                        guint         prop_id,
+                                        const GValue *value,
+                                        GParamSpec   *pspec)
+{
+	GeditFileBrowserPlugin *plugin = GEDIT_FILE_BROWSER_PLUGIN (object);
+
+	switch (prop_id)
+	{
+		case PROP_WINDOW:
+			plugin->priv->window = GEDIT_WINDOW (g_value_dup_object (value));
+			break;
+
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+			break;
+	}
+}
+
+static void
+gedit_file_browser_plugin_get_property (GObject    *object,
+                                        guint       prop_id,
+                                        GValue     *value,
+                                        GParamSpec *pspec)
+{
+	GeditFileBrowserPlugin *plugin = GEDIT_FILE_BROWSER_PLUGIN (object);
+
+	switch (prop_id)
+	{
+		case PROP_WINDOW:
+			g_value_set_object (value, plugin->priv->window);
+			break;
+
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+			break;
+	}
+}
+
 static void
 on_end_loading_cb (GeditFileBrowserStore  *store,
                    GtkTreeIter            *iter,
@@ -402,9 +487,6 @@ on_action_open_terminal (GtkAction              *action,
                          GeditFileBrowserPlugin *plugin)
 {
 	GeditFileBrowserPluginPrivate *priv = plugin->priv;
-	gchar *terminal;
-	gchar *local;
-	gchar *argv[2];
 	GFile *file;
 
 	GtkTreeIter iter;
@@ -421,27 +503,32 @@ on_action_open_terminal (GtkAction              *action,
 	                    &file,
 	                    -1);
 
-	if (file == NULL)
-		return;
+	if (file)
+	{
+		gchar *terminal;
+		gchar *local;
+		gchar *argv[2];
 
-	terminal = get_terminal (plugin);
+		terminal = get_terminal (plugin);
 
-	local = g_file_get_path (file);
+		local = g_file_get_path (file);
 
-	argv[0] = terminal;
-	argv[1] = NULL;
+		argv[0] = terminal;
+		argv[1] = NULL;
 
-	g_spawn_async (local,
-	               argv,
-	               NULL,
-	               G_SPAWN_SEARCH_PATH,
-	               NULL,
-	               NULL,
-	               NULL,
-	               NULL);
+		g_spawn_async (local,
+			       argv,
+			       NULL,
+			       G_SPAWN_SEARCH_PATH,
+			       NULL,
+			       NULL,
+			       NULL,
+			       NULL);
 
-	g_free (terminal);
-	g_free (local);
+		g_free (terminal);
+		g_free (local);
+		g_object_unref (file);
+	}
 }
 
 static void
@@ -453,7 +540,6 @@ on_selection_changed_cb (GtkTreeSelection       *selection,
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	gboolean sensitive;
-	GFile *location;
 
 	tree_view = GTK_TREE_VIEW (gedit_file_browser_widget_get_browser_view (priv->tree_widget));
 	model = gtk_tree_view_get_model (tree_view);
@@ -465,11 +551,21 @@ on_selection_changed_cb (GtkTreeSelection       *selection,
 
 	if (sensitive)
 	{
+		GFile *location;
+
 		gtk_tree_model_get (model, &iter,
 				    GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION,
 				    &location, -1);
 
-		sensitive = gedit_utils_location_has_file_scheme (location);
+		if (location)
+		{
+			sensitive = gedit_utils_location_has_file_scheme (location);
+			g_object_unref (location);
+		}
+		else
+		{
+			sensitive = FALSE;
+		}
 	}
 
 	gtk_action_set_sensitive (
@@ -511,8 +607,7 @@ static GtkActionEntry extra_single_selection_actions[] = {
 };
 
 static void
-add_popup_ui (GeditWindow            *window,
-	      GeditFileBrowserPlugin *plugin)
+add_popup_ui (GeditFileBrowserPlugin *plugin)
 {
 	GeditFileBrowserPluginPrivate *priv = plugin->priv;
 	GtkUIManager *manager;
@@ -535,7 +630,7 @@ add_popup_ui (GeditWindow            *window,
 	gtk_action_group_add_actions (action_group,
 				      extra_single_selection_actions,
 				      G_N_ELEMENTS (extra_single_selection_actions),
-				      window);
+				      priv->window);
 	gtk_ui_manager_insert_action_group (manager, action_group, 0);
 	priv->single_selection_action_group = action_group;
 
@@ -552,8 +647,7 @@ add_popup_ui (GeditWindow            *window,
 }
 
 static void
-remove_popup_ui (GeditWindow            *window,
-		 GeditFileBrowserPlugin *plugin)
+remove_popup_ui (GeditFileBrowserPlugin *plugin)
 {
 	GeditFileBrowserPluginPrivate *priv = plugin->priv;
 	GtkUIManager *manager;
@@ -569,13 +663,12 @@ remove_popup_ui (GeditWindow            *window,
 }
 
 static void
-gedit_file_browser_plugin_update_state (GeditWindowActivatable *activatable,
-					GeditWindow            *window)
+gedit_file_browser_plugin_update_state (GeditWindowActivatable *activatable)
 {
 	GeditFileBrowserPluginPrivate *priv = GEDIT_FILE_BROWSER_PLUGIN (activatable)->priv;
 	GeditDocument *doc;
 
-	doc = gedit_window_get_active_document (window);
+	doc = gedit_window_get_active_document (priv->window);
 
 	gtk_action_set_sensitive (gtk_action_group_get_action (priv->action_group,
 	                                                       "SetActiveRoot"),
@@ -583,18 +676,17 @@ gedit_file_browser_plugin_update_state (GeditWindowActivatable *activatable,
 }
 
 static void
-gedit_file_browser_plugin_activate (GeditWindowActivatable *activatable,
-				    GeditWindow            *window)
+gedit_file_browser_plugin_activate (GeditWindowActivatable *activatable)
 {
 	GeditFileBrowserPlugin *plugin = GEDIT_FILE_BROWSER_PLUGIN (activatable);
-	GeditFileBrowserPluginPrivate *priv = plugin->priv;
+	GeditFileBrowserPluginPrivate *priv;
 	GeditPanel *panel;
 	GtkWidget *image;
 	GdkPixbuf *pixbuf;
 	GeditFileBrowserStore *store;
 	gchar *data_dir;
 
-	priv->window = window;
+	priv = plugin->priv;
 
 	data_dir = peas_extension_base_get_data_dir (PEAS_EXTENSION_BASE (activatable));
 	priv->tree_widget = GEDIT_FILE_BROWSER_WIDGET (gedit_file_browser_widget_new (data_dir));
@@ -602,7 +694,7 @@ gedit_file_browser_plugin_activate (GeditWindowActivatable *activatable,
 
 	g_signal_connect (priv->tree_widget,
 			  "location-activated",
-			  G_CALLBACK (on_location_activated_cb), window);
+			  G_CALLBACK (on_location_activated_cb), priv->window);
 
 	g_signal_connect (priv->tree_widget,
 			  "error", G_CALLBACK (on_error_cb), plugin);
@@ -615,7 +707,7 @@ gedit_file_browser_plugin_activate (GeditWindowActivatable *activatable,
 	g_signal_connect (priv->tree_widget,
 	                  "confirm-no-trash",
 	                  G_CALLBACK (on_confirm_no_trash_cb),
-	                  window);
+	                  priv->window);
 
 	g_signal_connect (gtk_tree_view_get_selection (GTK_TREE_VIEW
 			  (gedit_file_browser_widget_get_browser_view
@@ -630,7 +722,7 @@ gedit_file_browser_plugin_activate (GeditWindowActivatable *activatable,
 	                 FILEBROWSER_FILTER_PATTERN,
 	                 G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
 
-	panel = gedit_window_get_side_panel (window);
+	panel = gedit_window_get_side_panel (priv->window);
 	pixbuf = gedit_file_browser_utils_pixbuf_from_theme ("system-file-manager",
 	                                                     GTK_ICON_SIZE_MENU);
 
@@ -652,7 +744,7 @@ gedit_file_browser_plugin_activate (GeditWindowActivatable *activatable,
 	                      image);
 	gtk_widget_show (GTK_WIDGET (priv->tree_widget));
 
-	add_popup_ui (window, plugin);
+	add_popup_ui (plugin);
 
 	/* Install nautilus preferences */
 	install_nautilus_prefs (plugin);
@@ -679,22 +771,21 @@ gedit_file_browser_plugin_activate (GeditWindowActivatable *activatable,
 	g_signal_connect (store,
 			  "rename",
 			  G_CALLBACK (on_rename_cb),
-			  window);
+			  priv->window);
 
-	g_signal_connect (window,
+	g_signal_connect (priv->window,
 	                  "tab-added",
 	                  G_CALLBACK (on_tab_added_cb),
 	                  plugin);
 
 	/* Register messages on the bus */
-	gedit_file_browser_messages_register (window, priv->tree_widget);
+	gedit_file_browser_messages_register (priv->window, priv->tree_widget);
 
-	gedit_file_browser_plugin_update_state (activatable, window);
+	gedit_file_browser_plugin_update_state (activatable);
 }
 
 static void
-gedit_file_browser_plugin_deactivate (GeditWindowActivatable *activatable,
-				      GeditWindow            *window)
+gedit_file_browser_plugin_deactivate (GeditWindowActivatable *activatable)
 {
 	GeditFileBrowserPlugin *plugin = GEDIT_FILE_BROWSER_PLUGIN (activatable);
 	GeditFileBrowserPluginPrivate *priv = plugin->priv;
@@ -702,10 +793,10 @@ gedit_file_browser_plugin_deactivate (GeditWindowActivatable *activatable,
 
 
 	/* Unregister messages from the bus */
-	gedit_file_browser_messages_unregister (window);
+	gedit_file_browser_messages_unregister (priv->window);
 
 	/* Disconnect signals */
-	g_signal_handlers_disconnect_by_func (window,
+	g_signal_handlers_disconnect_by_func (priv->window,
 	                                      G_CALLBACK (on_tab_added_cb),
 	                                      plugin);
 
@@ -727,9 +818,9 @@ gedit_file_browser_plugin_deactivate (GeditWindowActivatable *activatable,
 					     priv->confirm_trash_handle);
 	}
 
-	remove_popup_ui (window, plugin);
+	remove_popup_ui (plugin);
 
-	panel = gedit_window_get_side_panel (window);
+	panel = gedit_window_get_side_panel (priv->window);
 	gedit_panel_remove_item (panel, GTK_WIDGET (priv->tree_widget));
 }
 
@@ -739,6 +830,10 @@ gedit_file_browser_plugin_class_init (GeditFileBrowserPluginClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
 	object_class->dispose = gedit_file_browser_plugin_dispose;
+	object_class->set_property = gedit_file_browser_plugin_set_property;
+	object_class->get_property = gedit_file_browser_plugin_get_property;
+
+	g_object_class_override_property (object_class, PROP_WINDOW, "window");
 
 	g_type_class_add_private (object_class,
 				  sizeof (GeditFileBrowserPluginPrivate));
@@ -999,13 +1094,20 @@ get_filename_from_path (GtkTreeModel *model,
 {
 	GtkTreeIter iter;
 	GFile *location;
+	gchar *ret = NULL;
 
 	gtk_tree_model_get_iter (model, &iter, path);
 	gtk_tree_model_get (model, &iter,
 			    GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION, &location,
 			    -1);
 
-	return gedit_file_browser_utils_file_basename (location);
+	if (location)
+	{
+		ret = gedit_file_browser_utils_file_basename (location);
+		g_object_unref (location);
+	}
+
+	return ret;
 }
 
 static gboolean
